twz_rt_fd_reopen

Function twz_rt_fd_reopen 

pub unsafe extern "C-unwind" fn twz_rt_fd_reopen(
    fd: descriptor,
    kind: open_kind,
    flags: u32,
    bind_info: *mut c_void,
    bind_info_len: usize,
) -> twz_error
Reopen a file descriptor with a new anon binding. The anon_kind remains unchanged. The value pointed to by bind_info is dependent on the kind specified in the first argument. For pipe, bind_info is ignored. For Socket* kinds, bind_info points to a socket_address.