rust_entry

Function rust_entry 

pub unsafe fn rust_entry(arg: *const RuntimeInfo, main: usize) -> !
Entry point for Rust code wishing to start from rt0.

Safety

Do not call this unless you are bootstrapping a runtime.